@@ -1008,6 +1008,28 @@ GPBOOST_C_EXPORT SEXP GPB_GetCGPreconditionerType_R(
 	SEXP handle
 );
 
+/*!
+* \brief  Returns the number of CG steps when the CG method was last run
+* \param handle Handle of booster
+* \param[out] num_cg_steps Number of CG steps
+* \return 0 when succeed, -1 when failure happens
+*/
+GPBOOST_C_EXPORT SEXP GPB_GetNumCGSteps_R(
+	SEXP handle,
+	SEXP num_cg_steps
+);
+
+/*!
+* \brief  Returns the number of CG steps when the CG method was last run for the SLQ method
+* \param handle Handle of booster
+* \param[out] num_cg_steps Number of CG steps
+* \return 0 when succeed, -1 when failure happens
+*/
+GPBOOST_C_EXPORT SEXP GPB_GetNumCGStepsTridiag_R(
+	SEXP handle,
+	SEXP num_cg_steps
+);
+
 /*!
 * \brief Set the type of likelihood
 * \param likelihood Likelihood name
