@@ -135,6 +135,16 @@ namespace GPBoost {
 
 		string_t GetCGPreconditionerType() const;
 
+		/*!
+		* \brief Returns the number of CG steps when the CG method was last run
+		*/
+		int GetNumCGSteps() const;
+
+		/*!
+		* \brief Returns the number of CG steps when the CG method was last run for the SLQ method
+		*/
+		int GetNumCGStepsTridiag() const;
+
 		/*!
 		* \brief Set configuration parameters for the optimizer
 		* \param init_cov_pars Initial values for covariance parameters of RE components
