@@ -130,6 +130,7 @@ public:
         if (iter >= param.max_linesearch)
         {
             x.noalias() = xp;
+            f.ResetProfiledOutVariablesToLag1();
             fx = fx_init;
             step = 0.;
             Log::REDebug("GPModel lbfgs: the line search routine reached the maximum number of iterations");
@@ -138,7 +139,6 @@ public:
         {
             Log::REDebug("LineSearch for 'lbfgs' finished after %d iterations, step length = %g", iter, step);
         }
-        f(x, grad, false, true);//calculate gradient
          
     }
 };
