@@ -1691,6 +1691,24 @@ GPBOOST_C_EXPORT int GPB_GetCGPreconditionerType(REModelHandle handle,
     char* out_str,
     int* num_char);
 
+/*!
+* \brief  Returns the number of CG steps when the CG method was last run
+* \param handle Handle of booster
+* \param[out] num_cg_steps Number of CG steps
+* \return 0 when succeed, -1 when failure happens
+*/
+GPBOOST_C_EXPORT int GPB_GetNumCGSteps(BoosterHandle handle,
+    int* num_cg_steps);
+
+/*!
+* \brief  Returns the number of CG steps when the CG method was last run for the SLQ method
+* \param handle Handle of booster
+* \param[out] num_cg_steps Number of CG steps
+* \return 0 when succeed, -1 when failure happens
+*/
+GPBOOST_C_EXPORT int GPB_GetNumCGStepsTridiag(BoosterHandle handle,
+    int* num_cg_steps);
+
 /*!
 * \brief Set the type of likelihood
 * \param handle Handle of REModel
